==> haskell-hscolour-1.24.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.1
id: hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc
key: hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc
license: LGPL
copyright: 2003-2016 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ANSI
    Language.Haskell.HsColour.Anchors Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: 33090a93f38d944f518123c3cd7ae06b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hscolour-1.24.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hscolour-1.24.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/hscolour-1.24.1
hs-libraries: HShscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc
depends:
    base-4.9.0.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.24.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24.1
id: hscolour-1.24.1-8bO2w1mmWhpHwQRVjkjSBA
key: hscolour-1.24.1-8bO2w1mmWhpHwQRVjkjSBA
license: LGPL
copyright: 2003-2016 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ANSI
    Language.Haskell.HsColour.Anchors Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
abi: e998c5c90769b1d14e007cebfd6eb405
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hscolour-1.24.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/hscolour-1.24.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/hscolour-1.24.1
hs-libraries: HShscolour-1.24.1-8bO2w1mmWhpHwQRVjkjSBA
depends:
    base-4.9.1.0 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
